/***************************************************************************
 *
 * tdenetman-plugin.h - A NetworkManager frontend for TDE 
 *
 * Copyright (C) 2006 Novell, Inc.
 *
 * Author: Helmut Schaa <hschaa@suse.de>, <helmut.schaa@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#ifndef TDENETWORKMANAGER_PLUGIN_H
#define TDENETWORKMANAGER_PLUGIN_H

#include <tqobject.h>
#include <kdemacros.h>

class KDE_EXPORT Plugin : public TQObject
{
	Q_OBJECT
  
	public:
		Plugin(TQObject*, const char*, const TQStringList&);
		~Plugin();
};

#endif /* TDENETWORKMANAGER_PLUGIN_H */
